FeatureConfigState class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeatureConfigState({@Default.new(IMap.empty()) IMap<String, Feature> features})
const
factory

Properties

copyWith → $FeatureConfigStateCopyWith<FeatureConfigState>
Create a copy of FeatureConfigState with the given fields replaced by the non-null parameter values.
no setterinherited
features → IMap<String, Feature>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEnabled(String key) bool

Available on FeatureConfigState, provided by the FeatureConfigStateExt extension

map<TResult extends Object?>(TResult $default(_FeatureConfigState value)) → TResult

Available on FeatureConfigState, provided by the FeatureConfigStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeatureConfigState value)?) → TResult?

Available on FeatureConfigState, provided by the FeatureConfigStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeatureConfigState value)?, {required TResult orElse()}) → TResult

Available on FeatureConfigState, provided by the FeatureConfigStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(IMap<String, Feature> features)?, {required TResult orElse()}) → TResult

Available on FeatureConfigState, provided by the FeatureConfigStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(IMap<String, Feature> features)) → TResult

Available on FeatureConfigState, provided by the FeatureConfigStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(IMap<String, Feature> features)?) → TResult?

Available on FeatureConfigState, provided by the FeatureConfigStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited